@@ -349,8 +349,6 @@ class PatientEventRecordSet(PatientRecordSet):
         same sub-class, enabling chaining of calls.
         """
 
-        
-
         return self.__class__([
             item for item in self.records
             if item[self.DATE_FIELD] and filter_fn(arrow.get(item[self.DATE_FIELD]))
@@ -714,13 +712,14 @@ class PrescriptionRecordSet(PatientRecordSet):
         return item['coding']
 
 
-class ProcedureRecordSet(PatientRecordSet):
+class ProcedureRecordSet(PatientEventRecordSet):
     VALID_SYSTEMS = [
         'cpt',
         'snomedct'
     ]
     PATIENT_FIELD = 'procedures'
     API_UPDATE_FIELD = 'procedures'
+    DATE_FIELD = 'datetimeOfService'
 
     @staticmethod
     def item_to_codes(item) -> List:
