@@ -42,6 +42,7 @@ from .internal.attrdict import AttrDict
 from .internal.string import snakecase
 from .metaclass import DeclarativeFieldsMetaclass
 from .patient import Patient
+from .intervention import Intervention
 from .recommendation import (
     Recommendation, LabRecommendation, PlanRecommendation,
     TaskRecommendation, ReferRecommendation, ImagingRecommendation,
@@ -168,7 +169,7 @@ class ProtocolResult:
         """
         Add a recommendation to the recommendations list.
         """
-        if len(args) > 0 and isinstance(args[0], Recommendation):
+        if len(args) > 0 and isinstance(args[0], (Recommendation, Intervention)):
             recommendation = args[0]
         else:
             recommendation = Recommendation(*args, **kwargs)
@@ -305,6 +306,9 @@ class ClinicalQualityMeasure(Protocol):
         super().__init__(**kwargs)
 
         self.context = context if context == CONTEXT_GUIDANCE else CONTEXT_REPORT
+        self.settings = AttrDict()
+        self.field_changes = {}
+
         self._results: Optional[ProtocolResult] = None
         self.canvas_updates = []
 
@@ -402,7 +406,15 @@ class ClinicalQualityMeasure(Protocol):
         return self._results
 
     def set_context(self, context: Dict = {}) -> None:
-        self.context = AttrDict(context)
+        """
+        Deprecated - using to populate settings and field changes for pre-2022-03 instances
+        Use set_settings and
+        """
+        self.settings = AttrDict(context.get('config', {}))
+        self.field_changes = context.get('change_info', {})
+
+    def set_settings(self, settings: Dict = {}) -> None:
+        self.settings = AttrDict(settings)
 
     def set_updates(self, canvas_updates: List[Dict]) -> None:
         self.canvas_updates = canvas_updates
@@ -475,10 +487,11 @@ class ClinicalQualityMeasure(Protocol):
     def group_question_responses(interview: Dict) -> Dict:
         result: Dict = {}
         qr_id_2_code: Dict = {}
-        for question in interview['questions']:
+
+        for question in interview.get("questions", []):
             qr_id_2_code[question['questionResponseId']] = question['code']
 
-        for response in interview['responses']:
+        for response in interview.get('responses', []):
             question_code = qr_id_2_code[response['questionResponseId']]
             if question_code not in result:
                 result[question_code] = []
